@@ -1,18 +1,18 @@
-__version__ = "0.11.4"
+__version__ = "1.3.1"
 __author__ = "Lightning-AI et al."
 __author_email__ = "name@pytorchlightning.ai"
 __license__ = "Apache-2.0"
 __copyright__ = f"Copyright (c) 2020-2023, {__author__}."
-__homepage__ = "https://github.com/Lightning-AI/metrics"
+__homepage__ = "https://github.com/Lightning-AI/torchmetrics"
 __docs__ = "PyTorch native Metrics"
-__docs_url__ = "https://torchmetrics.readthedocs.io/en/stable/"
+__docs_url__ = "https://lightning.ai/docs/torchmetrics/stable/"
 __long_doc__ = """
 Torchmetrics is a metrics API created for easy metric development and usage in both PyTorch and
 [PyTorch Lightning](https://pytorch-lightning.readthedocs.io/en/stable/). It was originally a part of
 Pytorch Lightning, but got split off so users could take advantage of the large collection of metrics
 implemented without having to install Pytorch Lightning (even though we would love for you to try it out).
-We currently have around 90+ metrics implemented and we continuously are adding more metrics, both within
-already covered domains (classification, regression ect.) but also new domains (object detection ect.).
+We currently have around 100+ metrics implemented and we continuously are adding more metrics, both within
+already covered domains (classification, regression etc.) but also new domains (object detection etc.).
 We make sure that all our metrics are rigorously tested such that you can trust them.
 """
 
