@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@ from typing import List, Optional, Sequence, Tuple, Union
 
 import torch
 from torch import Tensor
-from torch.nn import functional as F
+from torch.nn import functional as F  # noqa: N812
 from typing_extensions import Literal
 
 from torchmetrics.functional.image.helper import _gaussian_kernel_2d, _gaussian_kernel_3d, _reflection_pad_3d
@@ -24,19 +24,15 @@ from torchmetrics.utilities.distributed import reduce
 
 
 def _ssim_check_inputs(preds: Tensor, target: Tensor) -> Tuple[Tensor, Tensor]:
-    """Updates and returns variables required to compute Structural Similarity Index Measure. Checks for same shape
-    and type of the input tensors.
+    """Update and returns variables required to compute Structural Similarity Index Measure.
 
     Args:
         preds: Predicted tensor
         target: Ground truth tensor
-    """
 
+    """
     if preds.dtype != target.dtype:
-        raise TypeError(
-            "Expected `preds` and `target` to have the same data type."
-            f" Got preds: {preds.dtype} and target: {target.dtype}."
-        )
+        target = target.to(preds.dtype)
     _check_same_shape(preds, target)
     if len(preds.shape) not in (4, 5):
         raise ValueError(
@@ -52,13 +48,13 @@ def _ssim_update(
     gaussian_kernel: bool = True,
     sigma: Union[float, Sequence[float]] = 1.5,
     kernel_size: Union[int, Sequence[int]] = 11,
-    data_range: Optional[float] = None,
+    data_range: Optional[Union[float, Tuple[float, float]]] = None,
     k1: float = 0.01,
     k2: float = 0.03,
     return_full_image: bool = False,
     return_contrast_sensitivity: bool = False,
 ) -> Union[Tensor, Tuple[Tensor, Tensor]]:
-    """Computes Structual Similarity Index Measure.
+    """Compute Structural Similarity Index Measure.
 
     Args:
         preds: estimated image
@@ -72,12 +68,13 @@ def _ssim_update(
         k1: Parameter of SSIM.
         k2: Parameter of SSIM.
         return_full_image: If true, the full ``ssim`` image is returned as a second argument.
-            Mutually exlusive with ``return_contrast_sensitivity``
+            Mutually exclusive with ``return_contrast_sensitivity``
         return_contrast_sensitivity: If true, the contrast term is returned as a second argument.
             The luminance term can be obtained with luminance=ssim/contrast
             Mutually exclusive with ``return_full_image``
+
     """
-    is_3d = len(preds.shape) == 5
+    is_3d = preds.ndim == 5
 
     if not isinstance(kernel_size, Sequence):
         kernel_size = 3 * [kernel_size] if is_3d else 2 * [kernel_size]
@@ -114,6 +111,10 @@ def _ssim_update(
 
     if data_range is None:
         data_range = max(preds.max() - preds.min(), target.max() - target.min())
+    elif isinstance(data_range, tuple):
+        preds = torch.clamp(preds, min=data_range[0], max=data_range[1])
+        target = torch.clamp(target, min=data_range[0], max=data_range[1])
+        data_range = data_range[1] - data_range[0]
 
     c1 = pow(k1 * data_range, 2)
     c2 = pow(k2 * data_range, 2)
@@ -145,10 +146,7 @@ def _ssim_update(
 
     input_list = torch.cat((preds, target, preds * preds, target * target, preds * target))  # (5 * B, C, H, W)
 
-    if is_3d:
-        outputs = F.conv3d(input_list, kernel, groups=channel)
-    else:
-        outputs = F.conv2d(input_list, kernel, groups=channel)
+    outputs = F.conv3d(input_list, kernel, groups=channel) if is_3d else F.conv2d(input_list, kernel, groups=channel)
 
     output_list = outputs.split(preds.shape[0])
 
@@ -160,8 +158,8 @@ def _ssim_update(
     sigma_target_sq = output_list[3] - mu_target_sq
     sigma_pred_target = output_list[4] - mu_pred_target
 
-    upper = 2 * sigma_pred_target + c2
-    lower = sigma_pred_sq + sigma_target_sq + c2
+    upper = 2 * sigma_pred_target.to(dtype) + c2
+    lower = (sigma_pred_sq + sigma_target_sq).to(dtype) + c2
 
     ssim_idx_full_image = ((2 * mu_pred_target + c1) * upper) / ((mu_pred_sq + mu_target_sq + c1) * lower)
 
@@ -172,12 +170,15 @@ def _ssim_update(
 
     if return_contrast_sensitivity:
         contrast_sensitivity = upper / lower
-        contrast_sensitivity = contrast_sensitivity[..., pad_h:-pad_h, pad_w:-pad_w]
+        if is_3d:
+            contrast_sensitivity = contrast_sensitivity[..., pad_h:-pad_h, pad_w:-pad_w, pad_d:-pad_d]
+        else:
+            contrast_sensitivity = contrast_sensitivity[..., pad_h:-pad_h, pad_w:-pad_w]
         return ssim_idx.reshape(ssim_idx.shape[0], -1).mean(-1), contrast_sensitivity.reshape(
             contrast_sensitivity.shape[0], -1
         ).mean(-1)
 
-    elif return_full_image:
+    if return_full_image:
         return ssim_idx.reshape(ssim_idx.shape[0], -1).mean(-1), ssim_idx_full_image
 
     return ssim_idx.reshape(ssim_idx.shape[0], -1).mean(-1)
@@ -187,7 +188,7 @@ def _ssim_compute(
     similarities: Tensor,
     reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
 ) -> Tensor:
-    """Applies the specified reduction to pre-computed structural similarity.
+    """Apply the specified reduction to pre-computed structural similarity.
 
     Args:
         similarities: per image similarities for a batch of images.
@@ -199,6 +200,7 @@ def _ssim_compute(
 
     Returns:
         The reduced SSIM score
+
     """
     return reduce(similarities, reduction)
 
@@ -210,13 +212,13 @@ def structural_similarity_index_measure(
     sigma: Union[float, Sequence[float]] = 1.5,
     kernel_size: Union[int, Sequence[int]] = 11,
     reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
-    data_range: Optional[float] = None,
+    data_range: Optional[Union[float, Tuple[float, float]]] = None,
     k1: float = 0.01,
     k2: float = 0.03,
     return_full_image: bool = False,
     return_contrast_sensitivity: bool = False,
 ) -> Union[Tensor, Tuple[Tensor, Tensor]]:
-    """Computes Structual Similarity Index Measure.
+    """Compute Structural Similarity Index Measure.
 
     Args:
         preds: estimated image
@@ -232,7 +234,9 @@ def structural_similarity_index_measure(
             - ``'sum'``: takes the sum
             - ``'none'`` or ``None``: no reduction will be applied
 
-        data_range: Range of the image. If ``None``, it is determined from the image (max - min)
+        data_range:
+            the range of the data. If None, it is determined from the data (max - min). If a tuple is provided then
+            the range is calculated as the difference and input is clamped between the values.
         k1: Parameter of SSIM.
         k2: Parameter of SSIM.
         return_full_image: If true, the full ``ssim`` image is returned as a second argument.
@@ -257,11 +261,12 @@ def structural_similarity_index_measure(
             If one of the elements of ``sigma`` is not a ``positive number``.
 
     Example:
-        >>> from torchmetrics.functional import structural_similarity_index_measure
+        >>> from torchmetrics.functional.image import structural_similarity_index_measure
         >>> preds = torch.rand([3, 3, 256, 256])
         >>> target = preds * 0.75
         >>> structural_similarity_index_measure(preds, target)
         tensor(0.9219)
+
     """
     preds, target = _ssim_check_inputs(preds, target)
     similarity_pack = _ssim_update(
@@ -280,9 +285,9 @@ def structural_similarity_index_measure(
     if isinstance(similarity_pack, tuple):
         similarity, image = similarity_pack
         return _ssim_compute(similarity, reduction), image
-    else:
-        similarity = similarity_pack
-        return _ssim_compute(similarity, reduction)
+
+    similarity = similarity_pack
+    return _ssim_compute(similarity, reduction)
 
 
 def _get_normalized_sim_and_cs(
@@ -291,7 +296,7 @@ def _get_normalized_sim_and_cs(
     gaussian_kernel: bool = True,
     sigma: Union[float, Sequence[float]] = 1.5,
     kernel_size: Union[int, Sequence[int]] = 11,
-    data_range: Optional[float] = None,
+    data_range: Optional[Union[float, Tuple[float, float]]] = None,
     k1: float = 0.01,
     k2: float = 0.03,
     normalize: Optional[Literal["relu", "simple"]] = None,
@@ -319,7 +324,7 @@ def _multiscale_ssim_update(
     gaussian_kernel: bool = True,
     sigma: Union[float, Sequence[float]] = 1.5,
     kernel_size: Union[int, Sequence[int]] = 11,
-    data_range: Optional[float] = None,
+    data_range: Optional[Union[float, Tuple[float, float]]] = None,
     k1: float = 0.01,
     k2: float = 0.03,
     betas: Union[Tuple[float, float, float, float, float], Tuple[float, ...]] = (
@@ -331,15 +336,16 @@ def _multiscale_ssim_update(
     ),
     normalize: Optional[Literal["relu", "simple"]] = None,
 ) -> Tensor:
-    """Computes Multi-Scale Structual Similarity Index Measure.
+    """Compute Multi-Scale Structural Similarity Index Measure.
 
     Adapted from: https://github.com/jorge-pessoa/pytorch-msssim/blob/master/pytorch_msssim/__init__.py.
 
     Args:
         preds: estimated image
         target: ground truth image
-        kernel_size: size of the gaussian kernel
+        gaussian_kernel: If true, a gaussian kernel is used, if false a uniform kernel is used
         sigma: Standard deviation of the gaussian kernel
+        kernel_size: size of the gaussian kernel
         reduction: a method to reduce metric score over labels.
 
             - ``'elementwise_mean'``: takes the mean
@@ -362,10 +368,11 @@ def _multiscale_ssim_update(
             If the image height is smaller than ``(kernel_size[0] - 1) * max(1, (len(betas) - 1)) ** 2``.
         ValueError:
             If the image width is smaller than ``(kernel_size[0] - 1) * max(1, (len(betas) - 1)) ** 2``.
+
     """
     mcs_list: List[Tensor] = []
 
-    is_3d = len(preds.shape) == 5
+    is_3d = preds.ndim == 5
 
     if not isinstance(kernel_size, Sequence):
         kernel_size = 3 * [kernel_size] if is_3d else 2 * [kernel_size]
@@ -413,16 +420,14 @@ def _multiscale_ssim_update(
 
     betas = torch.tensor(betas, device=mcs_stack.device).view(-1, 1)
     mcs_weighted = mcs_stack**betas
-    mcs_per_image = torch.prod(mcs_weighted, axis=0)
-
-    return mcs_per_image
+    return torch.prod(mcs_weighted, axis=0)
 
 
 def _multiscale_ssim_compute(
     mcs_per_image: Tensor,
     reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
 ) -> Tensor:
-    """Applies the specified reduction to pre-computed multi-scale structural similarity.
+    """Apply the specified reduction to pre-computed multi-scale structural similarity.
 
     Args:
         mcs_per_image: per image similarities for a batch of images.
@@ -434,6 +439,7 @@ def _multiscale_ssim_compute(
 
     Returns:
         The reduced multi-scale structural similarity
+
     """
     return reduce(mcs_per_image, reduction)
 
@@ -445,30 +451,35 @@ def multiscale_structural_similarity_index_measure(
     sigma: Union[float, Sequence[float]] = 1.5,
     kernel_size: Union[int, Sequence[int]] = 11,
     reduction: Literal["elementwise_mean", "sum", "none", None] = "elementwise_mean",
-    data_range: Optional[float] = None,
+    data_range: Optional[Union[float, Tuple[float, float]]] = None,
     k1: float = 0.01,
     k2: float = 0.03,
     betas: Tuple[float, ...] = (0.0448, 0.2856, 0.3001, 0.2363, 0.1333),
     normalize: Optional[Literal["relu", "simple"]] = "relu",
 ) -> Tensor:
-    """Computes `MultiScaleSSIM`_, Multi-scale Structual Similarity Index Measure, which is a generalization of
-    Structual Similarity Index Measure by incorporating image details at different resolution scores.
+    """Compute `MultiScaleSSIM`_, Multi-scale Structural Similarity Index Measure.
+
+    This metric is a generalization of Structural Similarity Index Measure by incorporating image details at different
+    resolution scores.
 
     Args:
         preds: Predictions from model of shape ``[N, C, H, W]``
         target: Ground truth values of shape ``[N, C, H, W]``
-        kernel_size: size of the gaussian kernel
+        gaussian_kernel: If true, a gaussian kernel is used, if false a uniform kernel is used
         sigma: Standard deviation of the gaussian kernel
+        kernel_size: size of the gaussian kernel
         reduction: a method to reduce metric score over labels.
 
             - ``'elementwise_mean'``: takes the mean
             - ``'sum'``: takes the sum
             - ``'none'`` or ``None``: no reduction will be applied
 
-        data_range: Range of the image. If ``None``, it is determined from the image (max - min)
+        data_range:
+            the range of the data. If None, it is determined from the data (max - min). If a tuple is provided then
+            the range is calculated as the difference and input is clamped between the values.
         k1: Parameter of structural similarity index measure.
         k2: Parameter of structural similarity index measure.
-        betas: Exponent parameters for individual similarities and contrastive sensitivies returned by different image
+        betas: Exponent parameters for individual similarities and contrastive sensitivities returned by different image
             resolutions.
         normalize: When MultiScaleSSIM loss is used for training, it is desirable to use normalizes to improve the
             training stability. This `normalize` argument is out of scope of the original implementation [1], and it is
@@ -490,8 +501,9 @@ def multiscale_structural_similarity_index_measure(
             If one of the elements of ``sigma`` is not a ``positive number``.
 
     Example:
-        >>> from torchmetrics.functional import multiscale_structural_similarity_index_measure
-        >>> preds = torch.rand([3, 3, 256, 256], generator=torch.manual_seed(42))
+        >>> from torchmetrics.functional.image import multiscale_structural_similarity_index_measure
+        >>> gen = torch.manual_seed(42)
+        >>> preds = torch.rand([3, 3, 256, 256], generator=gen)
         >>> target = preds * 0.75
         >>> multiscale_structural_similarity_index_measure(preds, target, data_range=1.0)
         tensor(0.9627)
@@ -499,6 +511,7 @@ def multiscale_structural_similarity_index_measure(
     References:
         [1] Multi-Scale Structural Similarity For Image Quality Assessment by Zhou Wang, Eero P. Simoncelli and Alan C.
         Bovik `MultiScaleSSIM`_
+
     """
     if not isinstance(betas, tuple):
         raise ValueError("Argument `betas` is expected to be of a type tuple.")
