@@ -1,4 +1,4 @@
-# Copyright The PyTorch Lightning team.
+# Copyright The Lightning team.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import Any, List, Optional, Tuple, Union
+from typing import Any, List, Optional, Sequence, Tuple, Union
 
 from torch import Tensor
 from typing_extensions import Literal
@@ -25,10 +25,15 @@ from torchmetrics.functional.regression.kendall import (
 )
 from torchmetrics.metric import Metric
 from torchmetrics.utilities.data import dim_zero_cat
+from torchmetrics.utilities.imports import _MATPLOTLIB_AVAILABLE
+from torchmetrics.utilities.plot import _AX_TYPE, _PLOT_OUT_TYPE
+
+if not _MATPLOTLIB_AVAILABLE:
+    __doctest_skip__ = ["KendallRankCorrCoef.plot"]
 
 
 class KendallRankCorrCoef(Metric):
-    r"""Computes `Kendall Rank Correlation Coefficient`_:
+    r"""Compute `Kendall Rank Correlation Coefficient`_.
 
     .. math::
         tau_a = \frac{C - D}{C + D}
@@ -74,45 +79,45 @@ class KendallRankCorrCoef(Metric):
         ValueError: If ``t_test=True`` and ``alternative=None``
 
     Example (single output regression):
-        >>> import torch
+        >>> from torch import tensor
         >>> from torchmetrics.regression import KendallRankCorrCoef
-        >>> preds = torch.tensor([2.5, 0.0, 2, 8])
-        >>> target = torch.tensor([3, -0.5, 2, 1])
+        >>> preds = tensor([2.5, 0.0, 2, 8])
+        >>> target = tensor([3, -0.5, 2, 1])
         >>> kendall = KendallRankCorrCoef()
         >>> kendall(preds, target)
         tensor(0.3333)
 
     Example (multi output regression):
-        >>> import torch
         >>> from torchmetrics.regression import KendallRankCorrCoef
-        >>> preds = torch.tensor([[2.5, 0.0], [2, 8]])
-        >>> target = torch.tensor([[3, -0.5], [2, 1]])
+        >>> preds = tensor([[2.5, 0.0], [2, 8]])
+        >>> target = tensor([[3, -0.5], [2, 1]])
         >>> kendall = KendallRankCorrCoef(num_outputs=2)
         >>> kendall(preds, target)
         tensor([1., 1.])
 
     Example (single output regression with t-test):
-        >>> import torch
         >>> from torchmetrics.regression import KendallRankCorrCoef
-        >>> preds = torch.tensor([2.5, 0.0, 2, 8])
-        >>> target = torch.tensor([3, -0.5, 2, 1])
+        >>> preds = tensor([2.5, 0.0, 2, 8])
+        >>> target = tensor([3, -0.5, 2, 1])
         >>> kendall = KendallRankCorrCoef(t_test=True, alternative='two-sided')
         >>> kendall(preds, target)
         (tensor(0.3333), tensor(0.4969))
 
     Example (multi output regression with t-test):
-        >>> import torch
         >>> from torchmetrics.regression import KendallRankCorrCoef
-        >>> preds = torch.tensor([[2.5, 0.0], [2, 8]])
-        >>> target = torch.tensor([[3, -0.5], [2, 1]])
+        >>> preds = tensor([[2.5, 0.0], [2, 8]])
+        >>> target = tensor([[3, -0.5], [2, 1]])
         >>> kendall = KendallRankCorrCoef(t_test=True, alternative='two-sided', num_outputs=2)
         >>> kendall(preds, target)
         (tensor([1., 1.]), tensor([nan, nan]))
-    """
 
+    """
     is_differentiable = False
     higher_is_better = None
     full_state_update = True
+    plot_lower_bound: float = 0.0
+    plot_upper_bound: float = 1.0
+
     preds: List[Tensor]
     target: List[Tensor]
 
@@ -123,15 +128,15 @@ class KendallRankCorrCoef(Metric):
         alternative: Optional[Literal["two-sided", "less", "greater"]] = "two-sided",
         num_outputs: int = 1,
         **kwargs: Any,
-    ):
+    ) -> None:
         super().__init__(**kwargs)
         if not isinstance(t_test, bool):
             raise ValueError(f"Argument `t_test` is expected to be of a type `bool`, but got {type(t_test)}.")
         if t_test and alternative is None:
             raise ValueError("Argument `alternative` is required if `t_test=True` but got `None`.")
 
-        self.variant = _MetricVariant.from_str(variant)
-        self.alternative = _TestAlternative.from_str(alternative) if t_test and alternative else None
+        self.variant = _MetricVariant.from_str(str(variant))
+        self.alternative = _TestAlternative.from_str(str(alternative)) if t_test else None
         self.num_outputs = num_outputs
 
         self.add_state("preds", [], dist_reduce_fx="cat")
@@ -148,12 +153,55 @@ class KendallRankCorrCoef(Metric):
         )
 
     def compute(self) -> Union[Tensor, Tuple[Tensor, Tensor]]:
-        """Compute Kendall rank correlation coefficient, and optionally p-value of corresponding statistical
-        test."""
+        """Compute Kendall rank correlation coefficient, and optionally p-value of corresponding statistical test."""
         preds = dim_zero_cat(self.preds)
         target = dim_zero_cat(self.target)
-        tau, p_value = _kendall_corrcoef_compute(preds, target, self.variant, self.alternative)
+        tau, p_value = _kendall_corrcoef_compute(
+            preds, target, self.variant, self.alternative  # type: ignore[arg-type]  # todo
+        )
 
         if p_value is not None:
             return tau, p_value
         return tau
+
+    def plot(
+        self, val: Optional[Union[Tensor, Sequence[Tensor]]] = None, ax: Optional[_AX_TYPE] = None
+    ) -> _PLOT_OUT_TYPE:
+        """Plot a single or multiple values from the metric.
+
+        Args:
+            val: Either a single result from calling `metric.forward` or `metric.compute` or a list of these results.
+                If no value is provided, will automatically call `metric.compute` and plot that result.
+            ax: An matplotlib axis object. If provided will add plot to that axis
+
+        Returns:
+            Figure and Axes object
+
+        Raises:
+            ModuleNotFoundError:
+                If `matplotlib` is not installed
+
+        .. plot::
+            :scale: 75
+
+            >>> from torch import randn
+            >>> # Example plotting a single value
+            >>> from torchmetrics.regression import KendallRankCorrCoef
+            >>> metric = KendallRankCorrCoef()
+            >>> metric.update(randn(10,), randn(10,))
+            >>> fig_, ax_ = metric.plot()
+
+        .. plot::
+            :scale: 75
+
+            >>> from torch import randn
+            >>> # Example plotting multiple values
+            >>> from torchmetrics.regression import KendallRankCorrCoef
+            >>> metric = KendallRankCorrCoef()
+            >>> values = []
+            >>> for _ in range(10):
+            ...     values.append(metric(randn(10,), randn(10,)))
+            >>> fig, ax = metric.plot(values)
+
+        """
+        return self._plot(val, ax)
